package com.srs.staff.mapper;

import java.util.List;

import com.srs.staff.domain.StaffOneStopRoomOpeningHours;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

/**
 * 一站式社区-功能房开放时间Mapper接口
 *
 * @author chc
 * @date 2024-08-13
 */
public interface StaffOneStopRoomOpeningHoursMapper extends BaseMapper<StaffOneStopRoomOpeningHours> {
    /**
     * 查询一站式社区-功能房开放时间
     *
     * @param ohId 一站式社区-功能房开放时间主键
     * @return 一站式社区-功能房开放时间
     */
    public StaffOneStopRoomOpeningHours selectStaffOneStopRoomOpeningHoursByOhId(Long ohId);

    /**
     * 查询一站式社区-功能房开放时间
     *
     * @param roomNo 一站式社区-功能房开放时间主键
     * @return 一站式社区-功能房开放时间
     */
    public StaffOneStopRoomOpeningHours selectStaffOneStopRoomOpeningHoursByRoomNo(String roomNo);
    /**
     * 查询一站式社区-功能房开放时间
     *
     * @param rtNo 一站式社区-功能房开放时间主键
     * @return 一站式社区-功能房开放时间
     */
    public StaffOneStopRoomOpeningHours selectStaffOneStopRoomOpeningHoursByRtNo(String rtNo);

    /**
     * 查询一站式社区-功能房开放时间
     *
     * @param ohWeekday 一站式社区-功能房开放时间主键
     * @return 一站式社区-功能房开放时间
     */
    public List<StaffOneStopRoomOpeningHours> selectStaffOneStopRoomOpeningHoursByOhWeekday(@Param("roomNo") String roomNo, @Param("ohWeekday") String ohWeekday);

    /**
     * 查询一站式社区-功能房开放时间列表
     *
     * @param staffOneStopRoomOpeningHours 一站式社区-功能房开放时间
     * @return 一站式社区-功能房开放时间集合
     */
    List<StaffOneStopRoomOpeningHours> selectStaffOneStopRoomOpeningHoursList(StaffOneStopRoomOpeningHours staffOneStopRoomOpeningHours);

    /**
     * 新增一站式社区-功能房开放时间
     *
     * @param staffOneStopRoomOpeningHours 一站式社区-功能房开放时间
     * @return 结果
     */
    int insertStaffOneStopRoomOpeningHours(StaffOneStopRoomOpeningHours staffOneStopRoomOpeningHours);

    /**
     * 批量新增一站式社区-功能房开放时间
     *
     * @param staffOneStopRoomOpeningHoursList 一站式社区-功能房开放时间
     * @return 结果
     */
    int insertStaffOneStopRoomOpeningHoursBatch(List<StaffOneStopRoomOpeningHours> staffOneStopRoomOpeningHoursList);

    /**
     * 修改一站式社区-功能房开放时间
     *
     * @param staffOneStopRoomOpeningHours 一站式社区-功能房开放时间
     * @return 结果
     */
    int updateStaffOneStopRoomOpeningHours(StaffOneStopRoomOpeningHours staffOneStopRoomOpeningHours);

    /**
     * 批量修改一站式社区-功能房开放时间
     *
     * @param staffOneStopRoomOpeningHoursList 一站式社区-功能房开放时间
     * @return 结果
     */
    int batchUpdateStaffOneStopRoomOpeningHours(List<StaffOneStopRoomOpeningHours> staffOneStopRoomOpeningHoursList);

    /**
     * 删除一站式社区-功能房开放时间
     *
     * @param ohId 一站式社区-功能房开放时间主键
     * @return 结果
     */
    int deleteStaffOneStopRoomOpeningHoursByOhId(Long ohId);

    /**
     * 批量删除一站式社区-功能房开放时间
     *
     * @param ohIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteStaffOneStopRoomOpeningHoursByOhIds(Long[] ohIds);
}
